#
# spec file for package python-audible
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-audible
Version:        0.10.0
Release:        2.2
Summary:        A(Sync) Interface for internal Audible API
License:        AGPL-3.0-only
URL:            https://github.com/mkb79/audible
Source:         https://files.pythonhosted.org/packages/source/a/audible/audible-%{version}.tar.gz
# PATCH-FIX-OPENSUSE remove-python-restriction.patch
Patch1:         remove-python-restriction.patch
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module httpx >= 0.20.0}
BuildRequires:  %{python_module pbkdf2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pyaes}
BuildRequires:  %{python_module rsa}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow
Requires:       python-beautifulsoup4
Requires:       python-httpx >= 0.20.0
Requires:       python-pbkdf2
Requires:       python-pyaes
Requires:       python-rsa
Suggests:       python-sphinx
Suggests:       python-sphinx_rtd_theme
Suggests:       python-sphinxcontrib-httpdomain
Suggests:       python-sphinx-autodoc-typehints
BuildArch:      noarch
%python_subpackages

%description
A(Sync) Interface for internal Audible API written in pure Python.

%prep
%autosetup -n audible-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/audible
%{python_sitelib}/audible-%{version}*-info

%changelog
* Tue Nov 26 2024 Nico Krapp <nico.krapp@suse.com>
- Add remove-python-restriction.patch to enable build for python313
* Fri Sep 27 2024 Daniel Garcia <daniel.garcia@suse.com>
- Fix license
- Make files more specific
* Thu Sep 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.0:
  * Fix autodetect_locale function
  * Drop support for Python 3.8 and 3.9
  * Add support for Python 3.12
- Drop audible-pyver.patch
* Thu Sep 19 2024 Michael Vetter <mvetter@suse.com>
- Add audible-pyver.patch:
  Patch out Python version requirement. See gh/mkb79/Audible#510
* Fri Sep  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.9.1
  * fix: fix login issues on brazilian marketplace (#204)
* Fri Sep  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.9.0:
  * ci: update release workflow (#181)
  * build: bump poetry and virtualenv (#150)
  * style(login.py): restyle line length (#149)
  * fix: login.py MFA form id updated (#128)
  * 116 switch to poetry implement ci+cd remove python version < 38 (#129)
  * remove pdf_url, add rights, customer_rights product_details (#126)
  * Fix spelling mistake in index.rst file (#125)
  * Update external_api.rst (#121)
  * Update external_api.rst (#115)
  * Multiple fixes for XXTEA encryption/decryption in metadata module (#109)
  * Grammar check on authorization.rst (#105)
  * Additional catalog/products response groups. (#96)
  * feat: add brazilian marketplace (#195)
* Wed Nov  9 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.8.2:
  * Allow httpx v0.23.x to fix a security issue in httpx
* Wed Nov  9 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.8.1:
  * fix a bug in Client.delete and AsyncClient.delete method
* Wed Nov  9 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.8.0:
  Added:
  * full support of pre-Amazon accounts (e.g. refresh access token,
    deregister device)
  * Client and AsynClient now accepts session kwargs which are
    bypassed to the underlying httpx Client
  * a respone_callback can now be set to Client and AsyncClient
    class to allow custom preparation of response output
  * An absolut url can now be passed to a client get, post, delete
    and put method as the path arg. So in most cases the client
    raw_request method is not needed anymore.
  Changed:
  * rename (and rework) Client._split_kwargs to Client._prepare_params
* Fri Apr  8 2022 Michael Vetter <mvetter@suse.com>
- Initial package of python-audible 0.7.2 for openSUSE
